@@ -18,6 +18,7 @@ import itertools
 from pathlib import Path
 from typing import cast, Dict, List, Optional
 from collections import namedtuple
+from fs.errors import FSError
 from flask import jsonify
 from airflow import configuration
 from airflow_code_editor.commons import (
@@ -127,7 +128,7 @@ def read_mount_points_config() -> Dict[str, MountPoint]:
                 k, v = part.split('=')
                 mount_conf[k] = v
             config[mount_conf['name']] = MountPoint(
-                path=mount_conf['path'], default=False
+                path=mount_conf['path'], default=mount_conf['name'] == ROOT_MOUNTPOUNT
             )
         except Exception:
             pass
@@ -148,7 +149,9 @@ def read_mount_points_config() -> Dict[str, MountPoint]:
             break
         name = configuration.conf.get(PLUGIN_NAME, 'mount{}_name'.format(suffix))
         path = configuration.conf.get(PLUGIN_NAME, 'mount{}_path'.format(suffix))
-        config[name] = MountPoint(path=path, default=False)
+        config[name] = MountPoint(
+            path=path, default=mount_conf['name'] == ROOT_MOUNTPOUNT
+        )
     return config
 
 
@@ -156,6 +159,8 @@ def error_message(ex: Exception) -> str:
     "Get exception error message"
     if ex is None:
         return ''
+    elif isinstance(ex, FSError):
+        return str(ex)
     elif hasattr(ex, 'strerror'):
         return ex.strerror
     elif hasattr(ex, 'message'):
